OC.L10N.register(
    "spreed",
    {
    "a conversation" : "דיון",
    "(Duration %s)" : "(משך %s)",
    "You attended a call with {user1}" : "הצטרפת לשיחה עם {user1}",
    "_%n guest_::_%n guests_" : ["אורח/ת 1","%n אורחים","%n אורחים","%n אורחים"],
    "You attended a call with {user1} and {user2}" : "השתתפת בשיחה עם {user1} ועם {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "השתתפת בשיחה עם {user1}, {user2} ועם {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "השתתפת בשיחה עם {user1}, {user2}, {user3} ועם {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "השתתפת בשיחה עם {user1}, {user2}, {user3}, {user4} ועם {user5}",
    "_%n other_::_%n others_" : ["מישהו נוסף","%n נוספים","%n נוספים","%n נוספים"],
    "{actor} invited you to {call}" : "הוזמנת אל {call} על ידי {actor}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "הוזמנת ל<strong>דיון</strong> או שקיבלת <strong>שיחה</strong>",
    "Talk" : "שיחה",
    "Guest" : "אורח/ת",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "ברוך בואך ל־Talk מבית Nextcloud!\nבדיון הזה נעדכן אותך בנוגע לתכונות החדשות שזמינות ב־Talk מבית Nextcloud.",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- ניתן מעתה להשתמש ב־Microsoft Edge וב־Safari כדי להשתת, בשיחות שמע ווידאו",
    "There are currently no commands available." : "אין פקודות זמינות.",
    "The command does not exist" : "הפקודה לא קיימת",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "אירעה שגיאה בעת הפעלת הפקודה. נא לבקש מהנהלת המערכת לבדוק את יומן התיעוד.",
    "{actor} created the conversation" : "הדיון נוצר על ידי {actor}",
    "You created the conversation" : "יצרת את הדיון",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "השם של הדיון השתנה מ־„%1$s” ל־„%2$s” על ידי {actor}",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "שינית את שם הדיון מהשם „%1$s” לשם „%2$s”",
    "{actor} started a call" : "שיחה החלה על ידי {actor}",
    "You started a call" : "התחלת שיחה",
    "{actor} joined the call" : "{actor} מעכשיו בשיחה",
    "You joined the call" : "הצטרפת לשיחה",
    "{actor} left the call" : "{actor} לא בשיחה עוד",
    "You left the call" : "עזבת את השיחה",
    "{actor} unlocked the conversation" : "הדיון שוחרר על ידי {actor}",
    "You unlocked the conversation" : "שחררת את הדיון",
    "{actor} locked the conversation" : "הדיון ננעל על ידי {actor}",
    "You locked the conversation" : "נעלת את הדיון",
    "The conversation is now open to everyone" : "הדיון מעתה פתוח לכול",
    "{actor} opened the conversation to everyone" : "הדיון נפתח לכול על ידי {actor}",
    "You opened the conversation to everyone" : "פתחת את הדיון לכול",
    "{actor} restricted the conversation to moderators" : "הדיון הוגבל למפקחים על ידי {actor}",
    "You restricted the conversation to moderators" : "הגבלת את הדיון למפקחים",
    "{actor} allowed guests" : "אורחים הורשו על ידי {actor}",
    "You allowed guests" : "הרשית אורחים",
    "An administrator allowed guests" : "ההנהלה איפשרה אורחים",
    "{actor} disallowed guests" : "אורחים נאסרו על ידי {actor}",
    "You disallowed guests" : "אסרת אורחים",
    "An administrator disallowed guests" : "ההנהלה אסרה על אורחים",
    "{actor} set a password" : "הוגדרה ססמה על ידי {actor}",
    "You set a password" : "הגדרת ססמה",
    "An administrator set a password" : "ההנהלה הגדירה ססמה",
    "{actor} removed the password" : "הססמה הוסרה על ידי {actor}",
    "You removed the password" : "הסרת את הססמה",
    "An administrator removed the password" : "הססמה הוסרה על ידי ההנהלה",
    "{actor} added {user}" : "ההוספה של {user} בוצעה על ידי {actor}",
    "You joined the conversation" : "הצטרפת לדיון",
    "{actor} joined the conversation" : "הצטרפות של {actor} לדיון",
    "You added {user}" : "הוספת את {user}",
    "{actor} added you" : "נוספת על ידי {actor}",
    "An administrator added you" : "נוספת על ידי ההנהלה",
    "An administrator added {user}" : "ההנהלה הוסיפה את {user}",
    "You left the conversation" : "עזבת את הדיון",
    "You removed group {group}" : "הסרת את הקבוצה {group}",
    "An administrator removed group {group}" : "ההנהלה הסירה את הקבוצה {group}",
    "You shared a file which is no longer available" : "שיתפת קובץ שאינו זמין עוד",
    "You updated the Matterbridge configuration" : "עדכנת את הגדרות ה־Matterbridge",
    "You stopped Matterbridge" : "עצרת את Matterbridge",
    "{actor} deleted a message" : "הודעה נמחקה על ידי {actor}",
    "You deleted a message" : "מחקת הודעה",
    "You missed a call from {user}" : "החמצת שיחה עם {user}",
    "Conversation invitation" : "הזמנה לדיון",
    "Click the button below to join." : "יש ללחוץ על הכפתור שלהלן כדי להצטרף.",
    "Meeting ID" : "מזהה פגישה",
    "Password request: %s" : "בקשת ססמה: %s",
    "Private conversation" : "דיון פרטי",
    "Deleted user (%s)" : "משתמש שנמחק (%s)",
    "{user} sent you a private message" : "התקבלה הודעה פרטית מאת {user}",
    "{user} invited you to a private conversation" : "הוזמנת לדיון פרטי על ידי {user}",
    "Join call" : "הצטרפות לשיחה",
    "{user} invited you to a group conversation: {call}" : "הוזמנת על ידי {user} לדיון קבוצתי: {call}",
    "Answer call" : "לענות לשיחה",
    "Call back" : "להתקשר בחזרה",
    "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
    "Open settings" : "פתיחת הגדרות",
    "Conversations" : "דיונים",
    "Messages" : "הודעות",
    "{user}" : "{user}",
    "Messages in other conversations" : "הודעות בדיונים אחרים",
    "The email address is invalid." : "כתובת הדוא״ל שגויה.",
    "Andorra" : "אנדורה",
    "United Arab Emirates" : "איחוד האמירויות הערביות",
    "Afghanistan" : "אפגניסטן",
    "Antigua and Barbuda" : "אנטיגואה וברבודה",
    "Anguilla" : "אנגווילה",
    "Albania" : "אלבניה",
    "Armenia" : "ארמניה",
    "Angola" : "אנגולה",
    "Antarctica" : "אנטארקטיקה",
    "Argentina" : "ארגנטינה",
    "American Samoa" : "סמואה האמריקנית",
    "Austria" : "אוסטריה",
    "Australia" : "אוסטרליה",
    "Aruba" : "ארובה",
    "Åland Islands" : "איי אולנד",
    "Azerbaijan" : "אזרבייג׳ן",
    "Bosnia and Herzegovina" : "בוסניה והרצגובינה",
    "Barbados" : "ברבדוס",
    "Bangladesh" : "בנגלדש",
    "Belgium" : "בלגיה",
    "Burkina Faso" : "בורקינה פאסו",
    "Bulgaria" : "בולגריה",
    "Bahrain" : "בחריין",
    "Burundi" : "בורונדי",
    "Benin" : "בנין",
    "Saint Barthélemy" : "סן ברתלמי",
    "Bermuda" : "ברמודה",
    "Brunei Darussalam" : "ברוניי משכן השלום",
    "Bonaire, Sint Eustatius and Saba" : "בונייר, סנט אוסטתיוס וסאבא",
    "Brazil" : "ברזיל",
    "Bahamas" : "איי בהאמה",
    "Bhutan" : "בהוטן",
    "Bouvet Island" : "האי בּוּבֶה",
    "Botswana" : "בוטסואנה",
    "Belarus" : "בלרוס",
    "Belize" : "בליז",
    "Canada" : "קנדה",
    "Cocos (Keeling) Islands" : "איי קוקוס קילינג",
    "Central African Republic" : "הרפובליקה המרכז-אפריקאית",
    "Congo" : "קונגו",
    "Switzerland" : "שווייץ",
    "Côte d'Ivoire" : "קוט דיוואר (חוף השנהב)",
    "Cook Islands" : "איי קוק",
    "Chile" : "צ׳ילה",
    "Cameroon" : "קמרון",
    "China" : "סין",
    "Colombia" : "קולומביה",
    "Costa Rica" : "קוסטה ריקה",
    "Cuba" : "קובה",
    "Cabo Verde" : "כף ורדה",
    "Curaçao" : "קוראסאו",
    "Christmas Island" : "אי חג המולד",
    "Cyprus" : "קפריסין",
    "Czechia" : "צ׳כיה",
    "Germany" : "גרמניה",
    "Djibouti" : "ג׳יבוטי",
    "Denmark" : "דנמרק",
    "Dominica" : "דומיניקה",
    "Dominican Republic" : "הרפובליקה הדומיניקנית",
    "Algeria" : "אלג׳יריה",
    "Ecuador" : "אקוודור",
    "Estonia" : "אסטוניה",
    "Egypt" : "מצרים",
    "Western Sahara" : "סהרה המערבית",
    "Eritrea" : "אריתריאה",
    "Spain" : "ספרד",
    "Ethiopia" : "אתיופיה",
    "Finland" : "פינלנד",
    "Fiji" : "פיג׳י",
    "Falkland Islands (Malvinas)" : "איי פוקלנד (מלווינאס)",
    "Faroe Islands" : "איי פארו",
    "France" : "צרפת",
    "Gabon" : "גבון",
    "United Kingdom of Great Britain and Northern Ireland" : "הממלכה המאוחדת של בריטניה הגדולה וצפון אירלנד",
    "Grenada" : "גרנדה",
    "Georgia" : "גאורגיה",
    "French Guiana" : "גיאנה הצרפתית",
    "Guernsey" : "גרנזי",
    "Ghana" : "גאנה",
    "Gibraltar" : "גיברלטר",
    "Greenland" : "גרינלנד",
    "Gambia" : "גמביה",
    "Guinea" : "גינאה",
    "Guadeloupe" : "גוואדלופ",
    "Equatorial Guinea" : "גינאה המשוונית",
    "Greece" : "יוון",
    "South Georgia and the South Sandwich Islands" : "איי ג׳ורג׳יה הדרומית ואיי סנדוויץ׳ הדרומיים",
    "Guatemala" : "גואטמלה",
    "Guam" : "גואם",
    "Guinea-Bissau" : "גינאה ביסאו",
    "Guyana" : "גיאנה",
    "Hong Kong" : "הונג קונג",
    "Heard Island and McDonald Islands" : "האי הרד ואיי מקדונלד",
    "Honduras" : "הונדורס",
    "Croatia" : "קרואטיה",
    "Haiti" : "האיטי",
    "Hungary" : "הונגריה",
    "Indonesia" : "אינדונזיה",
    "Ireland" : "אירלנד",
    "Israel" : "ישראל",
    "Isle of Man" : "האי מאן",
    "India" : "הודו",
    "British Indian Ocean Territory" : "הטריטוריה הבריטית באוקיינוס ההודי",
    "Iraq" : "עיראק",
    "Iceland" : "איסלנד",
    "Italy" : "איטליה",
    "Jersey" : "ג׳רזי",
    "Jamaica" : "ג׳מייקה",
    "Jordan" : "ירדן",
    "Japan" : "יפן",
    "Kenya" : "קניה",
    "Kyrgyzstan" : "קירגיסטן",
    "Cambodia" : "קמבודיה",
    "Kiribati" : "קיריבטי",
    "Comoros" : "קומורוס",
    "Saint Kitts and Nevis" : "סנט קיטס ונוויס",
    "Korea, Republic of" : "קוריאה, הרפובליקה של",
    "Kuwait" : "כווית",
    "Cayman Islands" : "איי קיימן",
    "Kazakhstan" : "קזחסטן",
    "Lao People's Democratic Republic" : "הרפובליקה הדמוקרטית העממית של אנשי הלאו",
    "Lebanon" : "לבנון",
    "Saint Lucia" : "סנט לוסיה",
    "Liechtenstein" : "ליכטנשטיין",
    "Sri Lanka" : "סרי לנקה",
    "Liberia" : "ליבריה",
    "Lesotho" : "לסוטו",
    "Lithuania" : "ליטא",
    "Luxembourg" : "לוקסמבורג",
    "Latvia" : "לטביה",
    "Libya" : "לוב",
    "Morocco" : "מרוקו",
    "Monaco" : "מונקו",
    "Moldova, Republic of" : "מודלובה, הרפובליקה של",
    "Montenegro" : "מונטנגרו",
    "Saint Martin (French part)" : "סן מרטן (העבר הצרפתי)",
    "Madagascar" : "מדגסקר",
    "Marshall Islands" : "איי מרשל",
    "Mali" : "מאלי",
    "Myanmar" : "מיאנמר",
    "Mongolia" : "מונגוליה",
    "Macao" : "מקאו",
    "Northern Mariana Islands" : "איי מריאנה הצפוניים",
    "Martinique" : "מרטיניק",
    "Mauritania" : "מאוריטניה",
    "Montserrat" : "מונטסראט",
    "Malta" : "מלטא",
    "Mauritius" : "מאוריציוס",
    "Maldives" : "האיים המלדיביים",
    "Malawi" : "מלאווי",
    "Mexico" : "מקסיקו",
    "Malaysia" : "מלזיה",
    "Mozambique" : "מוזמביק",
    "Namibia" : "נמיביה",
    "New Caledonia" : "קלדוניה החדשה",
    "Niger" : "ניז׳ר",
    "Norfolk Island" : "האי נורפוק",
    "Nigeria" : "ניגריה",
    "Nicaragua" : "ניקרגואה",
    "Netherlands" : "הולנד",
    "Norway" : "נורווגיה",
    "Nepal" : "נפאל",
    "Nauru" : "נאורו",
    "Niue" : "ניואה",
    "New Zealand" : "ניו זילנד",
    "Oman" : "עומאן",
    "Panama" : "פנמה",
    "Peru" : "פרו",
    "French Polynesia" : "פולינזיה הצרפתית",
    "Papua New Guinea" : "פפואה גינאה החדשה",
    "Philippines" : "הפיליפינים",
    "Pakistan" : "פקיסטן",
    "Poland" : "פולין",
    "Saint Pierre and Miquelon" : "סן-פייר ומיקלון",
    "Pitcairn" : "פיטקרן",
    "Puerto Rico" : "פוארטו ריקו",
    "Palestine, State of" : "הרשות הפלסטינית",
    "Portugal" : "פורטוגל",
    "Palau" : "פלאו",
    "Paraguay" : "פרגוואי",
    "Qatar" : "קטאר",
    "Réunion" : "ראוניון",
    "Romania" : "רומניה",
    "Serbia" : "סרביה",
    "Russian Federation" : "הפדרציה הרוסית",
    "Rwanda" : "רואנדה",
    "Saudi Arabia" : "ערב הסעודית",
    "Solomon Islands" : "איי שלמה",
    "Seychelles" : "איי סיישל",
    "Sudan" : "סודאן",
    "Sweden" : "שוודיה",
    "Singapore" : "סינגפור",
    "Saint Helena, Ascension and Tristan da Cunha" : "סנט הלנה, אסנשן וטריסטן דה קונה",
    "Slovenia" : "סלובניה",
    "Svalbard and Jan Mayen" : "סבאלברד ויאן מאיין",
    "Slovakia" : "סלובקיה",
    "Sierra Leone" : "סיירה לאון",
    "San Marino" : "סן מרינו",
    "Senegal" : "סנגל",
    "Somalia" : "סומליה",
    "Suriname" : "סורינאם",
    "South Sudan" : "דרום סודאן",
    "Sao Tome and Principe" : "סאו טומה ופרינסיפה",
    "El Salvador" : "אל סלוודור",
    "Sint Maarten (Dutch part)" : "סנט מארטן (העבר ההולנדי)",
    "Syrian Arab Republic" : "הרפובליקה הערבית הסורית",
    "Eswatini" : "אסוואטיני",
    "Turks and Caicos Islands" : "איי טרקס וקייקוס",
    "Chad" : "צ׳אד",
    "French Southern Territories" : "הארצות הדרומיות והאנטארקטיות של צרפת",
    "Togo" : "טוגו",
    "Thailand" : "תאילנד",
    "Tajikistan" : "טג׳יקיסטן",
    "Tokelau" : "טוקלאו",
    "Timor-Leste" : "מזרח טימור",
    "Turkmenistan" : "טורקמניסטן",
    "Tunisia" : "תוניסיה",
    "Tonga" : "טונגאית",
    "Turkey" : "טורקיה",
    "Trinidad and Tobago" : "טרינידד וטובגו",
    "Tuvalu" : "טובאלו",
    "Taiwan, Province of China" : "טאיוואן (מחוז סיני)",
    "Tanzania, United Republic of" : "טנזניה, הרפובליקה המאוחדת של",
    "Ukraine" : "אוקראינה",
    "Uganda" : "אוגנדה",
    "United States Minor Outlying Islands" : "האיים המרוחקים הקטנים של ארה״ב",
    "United States of America" : "ארצות הברית",
    "Uruguay" : "אורוגוואי",
    "Uzbekistan" : "אוזבקיסטן",
    "Holy See" : "הכס הקדוש",
    "Saint Vincent and the Grenadines" : "סנט וינסנט והגרנדינים",
    "Viet Nam" : "וייטנאם",
    "Vanuatu" : "ונואטו",
    "Wallis and Futuna" : "ואליס ופוטונה",
    "Samoa" : "סמואה",
    "Yemen" : "תימן",
    "Mayotte" : "מָיוֹט",
    "South Africa" : "דרום אפריקה",
    "Zambia" : "זמביה",
    "Zimbabwe" : "זימבבואה",
    "Invalid date, date format must be YYYY-MM-DD" : "תאריך לא חוקי, תבנית התאריך חייבת להיות YYYY-MM-DD",
    "Navigating away from the page will leave the call in {conversation}" : "ניווט מחוץ לעמוד תנתק את השיחה שב־{conversation}",
    "Leave call" : "יציאה מהשיחה",
    "Stay in call" : "להישאר בשיחה",
    "Discuss this file" : "לדון על הקובץ הזה",
    "Share this file with others to discuss it" : "שיתוף הקובץ הזה לדיונם של אחרים",
    "Share this file" : "שיתוף הקובץ הזה",
    "Join conversation" : "הצטרפות לדיון",
    "Request password" : "בקשת ססמה",
    "Error requesting the password." : "בקשת הססמה נכשלה.",
    "This conversation has ended" : "הדיון הסתיים",
    "Limit to groups" : "הגבלה לקבוצות",
    "Limit starting a call" : "הגבלת התחלת שיחה",
    "Limit starting calls" : "הגבלת התחלת שיחות",
    "Everyone" : "כולם",
    "Users and moderators" : "משתמשים ומפקחים",
    "Moderators only" : "מפקחים בלבד",
    "Save changes" : "שמירת שינויים",
    "Saving …" : "מתבצעת שמירה…",
    "Saved!" : "נשמר!",
    "None" : "אין",
    "User" : "משתמש",
    "Disabled" : "מושבת",
    "Moderators" : "מפקחים",
    "Users" : "משתמשים",
    "Commands" : "פקודות",
    "Beta" : "בטא",
    "Name" : "שם",
    "Command" : "פקודה",
    "Script" : "סקריפט",
    "Response to" : "תגובה אל",
    "Enabled for" : "מופעל עבור",
    "General settings" : "הגדרות כלליות",
    "Off" : "כבוי",
    "Language" : "שפה",
    "Country" : "מדינה",
    "Status" : "מצב",
    "Created at" : "נוצר ב־",
    "Pending" : "בהמתנה",
    "Error" : "שגיאה",
    "Blocked" : "נחסם",
    "Active" : "פעיל",
    "Expired" : "פג",
    "Matterbridge integration" : "שילוב עם Matterbridge",
    "Enable Matterbridge integration" : "הפעלת שילוב עם Matterbridge",
    "Downloading …" : "מתבצעת הורדה…",
    "Installed version: {version}" : "גרסה מותקנת: {version}",
    "Failed to execute Matterbridge binary." : "הפעלת הבינרי של Matterbridge נכשלה.",
    "Shared secret" : "סוד משותף",
    "Validate SSL certificate" : "אימות אישור SSL",
    "Delete this server" : "מחיקת השרת הזה",
    "Saved" : "נשמר",
    "Add a new server" : "הוספת שרת חדש",
    "STUN server URL" : "כתובת שרת STUN",
    "STUN servers" : "שרתי STUN",
    "A STUN server is used to determine the public IP address of participants behind a router." : "שרת STUN משמש לאיתור כתובת ה־IP הציבורית של המשתמשים מאחורי נתב.",
    "TURN server URL" : "כתובת שרת TURN",
    "TURN server protocols" : "פרוטוקולים לשרתים מסוג TURN",
    "Test this server" : "בדיקת השרת הזה",
    "TURN servers" : "שרתי TURN",
    "Copy link" : "העתקת קישור",
    "Waiting for others to join the call …" : "בהמתנה לאחרים להצטרף לשיחה…",
    "You can invite others in the participant tab of the sidebar" : "ניתן להזמין אחרים בלשונית המשתתפים בסרגל הצד",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "ניתן להזמין אחרים דרך לשונית המשתפים בסרגל הצד או לשתף את הקישור הזה כדי להזמין אחרים!",
    "Share this link to invite others!" : "יש לשתף את הקישור הזה כדי להזמין אחרים!",
    "Show your screen" : "הצגת המסך שלך",
    "Stop screensharing" : "הפסקת שיתוף המסך",
    "Settings" : "הגדרות",
    "Dismiss" : "התעלמות",
    "No audio" : "אין שמע",
    "Mute audio" : "השתקת שמע",
    "Disable video" : "השבתת וידאו",
    "Enable video" : "הפעלת וידאו",
    "Screensharing options" : "אפשרויות שיתוף מסך",
    "Enable screensharing" : "הפעלת שיתוף מסך",
    "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
    "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome כדי לשתף את המסך שלך.",
    "An error occurred while starting screensharing." : "אירעה שגיאה בעת התחלת שיתוף המסך.",
    "Back" : "חזרה",
    "You" : "אני",
    "Show screen" : "הצגת מסך",
    "Drop your files to upload" : "יש לגרור לכאן קבצים כדי להעלות",
    "Call in progress" : "מתנהלת שיחה",
    "Favorite" : "סימון כמועדף",
    "Conversation settings" : "הגדרות דיון",
    "Leave conversation" : "יציאה מהדיון",
    "Delete conversation" : "מחיקת דיון",
    "Password protection" : "הגנה בססמה",
    "Enter a password" : "נא להקליד ססמה",
    "Copy conversation link" : "העתקת קישור דיון",
    "Enable lobby" : "הפעלת לובי",
    "Start time (optional)" : "מועד התחלה (רשות)",
    "Save" : "שמירה",
    "Edit" : "עריכה",
    "Nextcloud URL" : "כתובת Nextcloud",
    "Nextcloud user" : "משתמש Nextcloud",
    "User password" : "ססמת משתמש",
    "Matrix server URL" : "כתובת שרת Matrix",
    "Matrix channel" : "ערוץ Matrix",
    "Mattermost server URL" : "כתובת שרת Mattermost",
    "Mattermost user" : "משתמש Mattermost",
    "Team name" : "שם צוות",
    "Channel name" : "שם ערוץ",
    "Rocket.Chat server URL" : "כתובת שרת Rocket.Chat",
    "Password" : "ססמה",
    "Rocket.Chat channel" : "ערוץ Rocket.Chat",
    "Zulip server URL" : "כתובת שרת Zulip",
    "Bot user name" : "שם המשתמש של הבוט",
    "Bot API key" : "מפתח ה־API של הבוט",
    "Zulip channel" : "ערוץ Zulip",
    "API token" : "אסימון API",
    "Slack channel" : "ערוץ Slack",
    "Server ID or name" : "מזהה או שם שרת",
    "Channel ID or name" : "מזהה ערוץ או שם",
    "Channel" : "ערוץ",
    "Login" : "התחבר",
    "Chat ID" : "מזהה צ׳אט",
    "Nickname" : "כינוי",
    "Connection password" : "ססמת התחברות",
    "IRC channel" : "ערוץ IRC",
    "Client ID" : "מזהה לקו",
    "Team ID" : "מזהה הקבוצה",
    "Thread ID" : "מזהה שרשור",
    "MUC server URL" : "כתובת שרת MUC",
    "Jabber ID" : "מזהה Jabber",
    "unknown state" : "מצב לא ידוע",
    "Bridge saved" : "הגישור נשמר",
    "Remove from favorites" : "הסרה מהמועדפים",
    "Add to favorites" : "הוספה למועדפים",
    "Loading" : "בטעינה",
    "Groups" : "קבוצות",
    "Circles" : "מעגלים",
    "Groups and circles" : "קבוצות ומעגלים",
    "Other sources" : "מקורות אחרים",
    "An error occurred while performing the search" : "אירעה שגיאה בעת ביצוע החיפוש",
    "Creating your conversation" : "הדיון שלך נוצר",
    "All set" : "הכול מוכן",
    "Error while creating the conversation" : "שגיאה ביצירת הדיון",
    "Link copied to the clipboard!" : "הקישור הועתק ללוח הגזירים!",
    "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
    "Password protect" : "הגנה בססמה",
    "Add participants" : "הוספת משתתפים",
    "Create conversation" : "יצירת דיון",
    "Close" : "סגירה",
    "Choose a password" : "בחירת ססמה",
    "Search participants" : "חיפוש משתתפים",
    "Conversation name" : "שם דיון",
    "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "בנך בהמתנה בלובי. פגישה זו זומנה ל־{startTime}",
    "Calls are not supported in your browser" : "אין תמיכה בשיחות בדפדפן שלך",
    "Access to microphone was denied" : "הגישה למיקרופון נדחתה",
    "Microphone" : "מיקרופון",
    "Camera" : "מצלמה",
    "Reply" : "תגובה",
    "Go to file" : "מעבר לקובץ",
    "[Unknown username]" : "[שם משתמש לא ידוע]",
    "Today" : "היום",
    "Yesterday" : "מחר",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Share files to the conversation" : "שיתוף קבצים לדיון",
    "Upload new files" : "העלאת קבצים חדשים",
    "Share from Files" : "שיתוף מקבצים",
    "Add emoji" : "הוספת אמוג׳י",
    "Send message" : "שליחת הודעה",
    "File to share" : "קובץ לשיתוף",
    "Invalid path selected" : "הנתיב שנבחר שגוי",
    "moderator" : "מפקח/ת",
    "guest" : "אורח",
    "Demote from moderator" : "הורדה מדרגת פיקוח",
    "Promote to moderator" : "קידום לדרגת פיקוח",
    "Remove group and members" : "הסרת קבוצה וחברים",
    "Remove participant" : "הסרת משתתף",
    "Add groups" : "הוספת קבוצות",
    "Add emails" : "הוספת כתובות דוא״ל",
    "Add circles" : "הוספת מעגלים",
    "Searching …" : "מתבצע חיפוש…",
    "No results" : "אין תוצאות",
    "Add users or groups" : "הוספת משתמשים או קבוצות",
    "Add groups or circles" : "הוספת קבוצות או מעגלים",
    "Add other sources" : "הוספת מקורות אחרים",
    "Participants" : "משתתפים",
    "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
    "Chat" : "צ׳אט",
    "Display name: " : "שם תצוגה:",
    "Choose devices" : "בחירת התקנים",
    "Attachments folder" : "תיקיית הקבצים המצורפים",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Search" : "חיפוש",
    "Shortcuts while in a call" : "קיצורי דרך בזמן שיחה",
    "Select location for attachments" : "בחירת מיקום לקבצים מצורפים",
    "Start call" : "התחלת שיחה",
    "Rename conversation" : "שינוי שם הדיון",
    "Mute others" : "השתקה של אחרים",
    "Speaker view" : "תצוגת דובר",
    "Grid view" : "תצוגת טבלה",
    "Send" : "שליחה",
    "Add more files" : "הוספת קבצים נוספים",
    "No unread mentions" : "אין אזכורים שלא נקראו",
    "Start a conversation" : "התחלת דיון",
    "Message without mention" : "הודעה ללא אזכור",
    "Mention myself" : "אזכור עצמי",
    "Mention room" : "אזכור חדר",
    "The conversation does not exist" : "הדיון לא קיים",
    "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
    "Select conversation" : "בחירת דיון",
    "Link to a conversation" : "קישור לדיון",
    "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
    "Error while sharing file" : "שגיאה בשיתוף הקובץ",
    "Default" : "בררת מחדל",
    "Speaker {number}" : "רמקול {number}",
    "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
    "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
    "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
    "WebRTC is not supported in your browser" : "בדפדפן שלך אין תמיכה ב־WebRTC",
    "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
    "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
    "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
    "TURN server" : "שרת TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
    "Signaling servers" : "שרתי איתות",
    "Android app" : "יישומון ל־Android",
    "iOS app" : "יישומון ל־iOS",
    "New in Talk 6" : "חדש ב־Talk 6",
    "New in Talk 7" : "חדש ב־Talk 7",
    "New in Talk 8" : "חדש ב־Talk 8",
    "UDP and TCP" : "UDP ו־TCP",
    "UDP only" : "UDP בלבד",
    "TCP only" : "TCP בלבד",
    "Mute audio (m)" : "השתקת שמע (m)",
    "Unmute audio (m)" : "ביטול השקת שמע (m)",
    "Disable video (v)" : "השבתת וידאו (v)",
    "Enable video (v)" : "הפעלת וידאו (v)",
    "Conversation, " : "דיון,",
    "Allow guests to join via link " : "לאפשר לאורחים להצטרף דרך קישור",
    "Remove" : "הסרה",
    "Bridge with other services" : "גישור עם שירותים אחרים",
    "More info on Matterbridge." : "מידע נוסף על Matterbridge.",
    "Enabled" : "מופעל",
    "User name or e-mail address" : "שם משתמש או כתובת דוא״ל",
    "Add new bridged channel" : "הוספת ערוץ מגושר חדש",
    "Participant settings" : "הגדרות משתתפים",
    "Add participants to the conversation" : "הוספת משתתפים לדיון",
    "Share link" : "שיתוף קישור",
    "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
    "Fullscreen (f)" : "מסך מלא (f)"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
